@@ -73,7 +73,9 @@
 #'     \item{`"lru"`}{
 #'       Least Recently Used. The least recently used objects will be removed.
 #'       This uses the filesystem's mtime property. When "lru" is used, each
-#'       `get()` is called, it will update the file's mtime.
+#'       `get()` is called, it will update the file's mtime using
+#'       [Sys.setFileTime()]. Note that on some platforms, the resolution of
+#'       [Sys.setFileTime()] may be low, one or two seconds.
 #'     }
 #'     \item{`"fifo"`}{
 #'       First-in-first-out. The oldest objects will be removed.
@@ -424,7 +426,7 @@ cache_disk <- function(
       info <- info[!rm_idx, ]
     }
 
-    prune_last_time_ <- as.numeric(current_time)
+    prune_last_time_ <<- as.numeric(current_time)
 
     invisible(TRUE)
   }
@@ -466,7 +468,7 @@ cache_disk <- function(
     file.remove(dir(dir_, "\\.rds$", full.names = TRUE))
     # Next remove dir recursively, including sentinel file.
     unlink(dir_, recursive = TRUE)
-    destroyed_ <- TRUE
+    destroyed_ <<- TRUE
     invisible(TRUE)
   }
 
@@ -475,7 +477,7 @@ cache_disk <- function(
         file.exists(file.path(dir_, "__destroyed__")))
     {
       # It's possible for another process to destroy a shared cache directory
-      destroyed_ <- TRUE
+      destroyed_ <<- TRUE
     }
 
     if (throw) {
@@ -508,13 +510,13 @@ cache_disk <- function(
   # future, the behavior may be customizable.
   prune_throttled_ <- function() {
     # Count the number of times prune() has been called.
-    prune_throttle_counter_ <- prune_throttle_counter_ + 1
+    prune_throttle_counter_ <<- prune_throttle_counter_ + 1
 
     if (prune_throttle_counter_ > prune_rate_ ||
-        prune_last_time_ - as.numeric(Sys.time()) > 5)
+        as.numeric(Sys.time()) - prune_last_time_ > 5)
     {
       prune()
-      prune_throttle_counter_ <- 0
+      prune_throttle_counter_ <<- 0
     }
   }
 
